import React, { forwardRef, useImperativeHandle } from 'react';
import Tooltip from 'rc-tooltip';
import classNames from 'classnames';
import { usePropsValue } from '../../utils/use-props-value';
import { mergeProps } from '../../utils/with-default-props';
import { withStopPropagation } from '../../utils/with-stop-propagation';
const classPrefix = `adm-popover`;
const enterClassName = 'entering';
const leaveClassName = 'leaving';
const defaultProps = {
  defaultVisible: false,
  stopPropagation: ['click']
};
export const Popover = forwardRef((p, ref) => {
  var _a;

  const props = mergeProps(defaultProps, p);
  const {
    mode = 'light'
  } = props;
  const [visible, setVisible] = usePropsValue({
    value: props.visible,
    defaultValue: props.defaultVisible,
    onChange: props.onVisibleChange
  });
  useImperativeHandle(ref, () => {
    return {
      show: () => setVisible(true),
      hide: () => setVisible(false),
      visible
    };
  }, [visible]);
  return withStopPropagation(props.stopPropagation, React.createElement(Tooltip, Object.assign({}, props, {
    overlayClassName: classNames(`${classPrefix}-${mode}`, props.overlayClassName),
    destroyTooltipOnHide: props.destroyOnHide,
    prefixCls: classPrefix,
    getTooltipContainer: props.getContainer || (() => document.body),
    visible: visible,
    arrowContent: React.createElement("span", {
      className: `${classPrefix}-arrow-content`
    }),
    onVisibleChange: setVisible,
    trigger: (_a = props.trigger) !== null && _a !== void 0 ? _a : [],
    motion: {
      motionName: {
        appear: enterClassName,
        appearActive: enterClassName,
        enter: enterClassName,
        enterActive: enterClassName,
        leaveActive: leaveClassName,
        leave: leaveClassName
      },
      motionDeadline: 200
    },
    overlay: React.createElement("div", {
      className: `${classPrefix}-inner-content`
    }, props.content)
  }), props.children));
});